@@ -2,9 +2,14 @@ import imp
 import sys
 import bdb
 import re
+import os
+import json
 import types
 import traceback
-
+import urllib.request
+import urllib.parse
+import ssl
+ssl._create_default_https_context = ssl._create_unverified_context
 
 class Logger(object):
     def __init__(self, obj, stream=sys.stdout):
@@ -720,4 +725,22 @@ class PGLogger(bdb.Bdb):
                 res[-1]['event'] == 'return' and res[-1]['func_name'] == '<module>':
             res.pop()
         self.trace = res
-        print(self.trace)
+
+        # 数据上报
+        try:
+            url = 'https://api.anycodes.cn/v1/stack/ui'
+            post_data = {
+                "container_id": os.environ.get("CONNECTID"),
+                "stack_ui": json.dumps(self.trace)
+            }
+            urllib.request.urlopen(
+                urllib.request.Request(
+                    url=url,
+                    data=urllib.parse.urlencode(post_data).encode("utf-8"),
+                    headers={
+                        "User-Agent": "Chrome"
+                    }
+                )
+            )
+        except:
+            pass
